@@ -57,17 +57,11 @@ class PTAppSystemAssignmentFilterSet(ChangeLoggedModelFilterSet):
 
 
 class PTWorkstationsFilterSet(NetBoxModelFilterSet):
-    class Meta:
-        model = PTWorkstations
-        fields = ['id', 'name', 'slug', 'description', 'ad_description',
-                  'CN', 'DistinguishedName', 'ad_guid', 'ad_description']
-
     def search(self, queryset, name, value):
         if not value.strip():
             return queryset
         return queryset.filter(
             Q(name__icontains=value) |
-            Q(slug__icontains=value) |
             Q(description__icontains=value) |
             Q(ad_description__icontains=value) |
             Q(CN__icontains=value) |
@@ -76,10 +70,15 @@ class PTWorkstationsFilterSet(NetBoxModelFilterSet):
             Q(ad_description__icontains=value)
         )
 
+    class Meta:
+        model = PTWorkstations
+        fields = ['id', 'name', 'description', 'ad_description',
+                  'CN', 'DistinguishedName', 'ad_guid', 'ad_description']
+
 
 class PTWorkstationsAssignmentFilterSet(ChangeLoggedModelFilterSet):
     content_type = ContentTypeFilter()
-    app_system_id = django_filters.ModelMultipleChoiceFilter(
+    pt_workstations_id = django_filters.ModelMultipleChoiceFilter(
         queryset=PTWorkstations.objects.all(),
         label='Workstation (ID)',
     )
