@@ -334,8 +334,7 @@ class PTWorkstationsAssignment(WebhooksMixin, ChangeLoggedModel):
 
     class Meta:
         ordering = ['pt_workstations']
-        unique_together = ('content_type', 'object_id',
-                           'pt_workstations')
+        unique_together = ('content_type', 'object_id', 'pt_workstations')
 
     def __str__(self):
         return str(self.pt_workstations)
