@@ -1,6 +1,6 @@
 from extras.plugins import PluginTemplateExtension
 from django.contrib.contenttypes.models import ContentType
-from .models import PTUEventAssignment, PTAppSystemAssignment, PTAppSystem, PTUsersAssignment, PTWorkstationsAssignment
+from .models import PTUEventAssignment, PTAppSystemAssignment
 
 
 class PTUEventVMPanel(PluginTemplateExtension):
@@ -112,48 +112,6 @@ class AppSystemDevicePanel(PluginTemplateExtension):
         })
 
 
-class PTUEventUsersPanel(PluginTemplateExtension):
-    model = 'ptuevents.ptusers'
-
-    def right_page(self):
-        user = self.context['object']
-        content_type_id = ContentType.objects.get_for_model(model=user).id
-        PTUEvent_ass = PTUsersAssignment.objects.filter(
-            object_id=user.id, content_type=content_type_id)
-        PTUEvents = []
-        for r in PTUEvent_ass:
-            PTUEvents.append({
-                'assignment_id': r.id,
-                'name': r.ptuevent,
-                'rel': r.relation.name
-            })
-
-        return self.render('ptuevents/ptuevent_panel.html', extra_context={
-            'PTUEvents': PTUEvents
-        })
-
-
-class PTUEventWorkstationPanel(PluginTemplateExtension):
-    model = 'ptuevents.ptworkstations'
-
-    def right_page(self):
-        ws = self.context['object']
-        content_type_id = ContentType.objects.get_for_model(model=ws).id
-        PTUEvent_ass = PTWorkstationsAssignment.objects.filter(
-            object_id=ws.id, content_type=content_type_id)
-        PTUEvents = []
-        for r in PTUEvent_ass:
-            PTUEvents.append({
-                'assignment_id': r.id,
-                'name': r.ptuevent,
-                'rel': r.relation.name
-            })
-
-        return self.render('ptuevents/ptuevent_panel.html', extra_context={
-            'PTUEvents': PTUEvents
-        })
-
-
 template_extensions = [AppSystemVMPanel, AppSystemDevicePanel, PTUEventVMPanel,
-                       PTUEventDevicePanel, PTUEventUsersPanel, PTUEventWorkstationPanel]
+                       PTUEventDevicePanel]
 
